/* Definitions mimicking those of ICU unicode/unorm.h */
#ifndef UNORM_H
#define UNORM_NONE	1 
#define UNORM_NFC	4
#define UNORM_NFD	2
#define UNORM_NFKC	5
#define UNORM_NFKD	3
#endif


